@@ -5,7 +5,7 @@
 %%% Created : 14 Jul 2009 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2016 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2017 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -751,7 +751,7 @@ warning(Code) when Code > 300, Code < 400 -> <<"\"\"">>.
 %% gen_server callbacks
 %%====================================================================
 init([]) ->
-    {A, B, C} = now(),
+    {A, B, C} = p1_time_compat:timestamp(),
     random:seed(A, B, C),
     ets:new(esip_config, [named_table, public]),
     set_config([]),
